@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.CCInfo import CCInfo
 from alipay.aop.api.domain.AssetDeliveryAddress import AssetDeliveryAddress
 from alipay.aop.api.domain.LogisticsInfo import LogisticsInfo
 from alipay.aop.api.domain.AssetDeliveryAddress import AssetDeliveryAddress
@@ -17,14 +18,25 @@ class AssetDeliveryItem(object):
         self._apply_order_id = None
         self._assign_item_id = None
         self._assign_out_order_id = None
+        self._biz_line = None
         self._biz_tag = None
         self._biz_type = None
+        self._custom_clearance = None
+        self._delivery_assign_order_item_id = None
+        self._delivery_process_no = None
+        self._delivery_process_supplier_id = None
+        self._delivery_process_supplier_name = None
+        self._delivery_supplier_full_name = None
+        self._delivery_supplier_id = None
+        self._delivery_supplier_name = None
+        self._ext_info = None
         self._from_address = None
         self._gmt_assign = None
         self._item_id = None
         self._item_name = None
         self._logistics_info = None
         self._memo = None
+        self._operate_info = None
         self._ou_code = None
         self._ou_name = None
         self._out_biz_no = None
@@ -79,6 +91,13 @@ class AssetDeliveryItem(object):
     def assign_out_order_id(self, value):
         self._assign_out_order_id = value
     @property
+    def biz_line(self):
+        return self._biz_line
+
+    @biz_line.setter
+    def biz_line(self, value):
+        self._biz_line = value
+    @property
     def biz_tag(self):
         return self._biz_tag
 
@@ -93,6 +112,72 @@ class AssetDeliveryItem(object):
     def biz_type(self, value):
         self._biz_type = value
     @property
+    def custom_clearance(self):
+        return self._custom_clearance
+
+    @custom_clearance.setter
+    def custom_clearance(self, value):
+        if isinstance(value, CCInfo):
+            self._custom_clearance = value
+        else:
+            self._custom_clearance = CCInfo.from_alipay_dict(value)
+    @property
+    def delivery_assign_order_item_id(self):
+        return self._delivery_assign_order_item_id
+
+    @delivery_assign_order_item_id.setter
+    def delivery_assign_order_item_id(self, value):
+        self._delivery_assign_order_item_id = value
+    @property
+    def delivery_process_no(self):
+        return self._delivery_process_no
+
+    @delivery_process_no.setter
+    def delivery_process_no(self, value):
+        self._delivery_process_no = value
+    @property
+    def delivery_process_supplier_id(self):
+        return self._delivery_process_supplier_id
+
+    @delivery_process_supplier_id.setter
+    def delivery_process_supplier_id(self, value):
+        self._delivery_process_supplier_id = value
+    @property
+    def delivery_process_supplier_name(self):
+        return self._delivery_process_supplier_name
+
+    @delivery_process_supplier_name.setter
+    def delivery_process_supplier_name(self, value):
+        self._delivery_process_supplier_name = value
+    @property
+    def delivery_supplier_full_name(self):
+        return self._delivery_supplier_full_name
+
+    @delivery_supplier_full_name.setter
+    def delivery_supplier_full_name(self, value):
+        self._delivery_supplier_full_name = value
+    @property
+    def delivery_supplier_id(self):
+        return self._delivery_supplier_id
+
+    @delivery_supplier_id.setter
+    def delivery_supplier_id(self, value):
+        self._delivery_supplier_id = value
+    @property
+    def delivery_supplier_name(self):
+        return self._delivery_supplier_name
+
+    @delivery_supplier_name.setter
+    def delivery_supplier_name(self, value):
+        self._delivery_supplier_name = value
+    @property
+    def ext_info(self):
+        return self._ext_info
+
+    @ext_info.setter
+    def ext_info(self, value):
+        self._ext_info = value
+    @property
     def from_address(self):
         return self._from_address
 
@@ -141,6 +226,13 @@ class AssetDeliveryItem(object):
     def memo(self, value):
         self._memo = value
     @property
+    def operate_info(self):
+        return self._operate_info
+
+    @operate_info.setter
+    def operate_info(self, value):
+        self._operate_info = value
+    @property
     def ou_code(self):
         return self._ou_code
 
@@ -247,6 +339,11 @@ class AssetDeliveryItem(object):
                 params['assign_out_order_id'] = self.assign_out_order_id.to_alipay_dict()
             else:
                 params['assign_out_order_id'] = self.assign_out_order_id
+        if self.biz_line:
+            if hasattr(self.biz_line, 'to_alipay_dict'):
+                params['biz_line'] = self.biz_line.to_alipay_dict()
+            else:
+                params['biz_line'] = self.biz_line
         if self.biz_tag:
             if hasattr(self.biz_tag, 'to_alipay_dict'):
                 params['biz_tag'] = self.biz_tag.to_alipay_dict()
@@ -257,6 +354,51 @@ class AssetDeliveryItem(object):
                 params['biz_type'] = self.biz_type.to_alipay_dict()
             else:
                 params['biz_type'] = self.biz_type
+        if self.custom_clearance:
+            if hasattr(self.custom_clearance, 'to_alipay_dict'):
+                params['custom_clearance'] = self.custom_clearance.to_alipay_dict()
+            else:
+                params['custom_clearance'] = self.custom_clearance
+        if self.delivery_assign_order_item_id:
+            if hasattr(self.delivery_assign_order_item_id, 'to_alipay_dict'):
+                params['delivery_assign_order_item_id'] = self.delivery_assign_order_item_id.to_alipay_dict()
+            else:
+                params['delivery_assign_order_item_id'] = self.delivery_assign_order_item_id
+        if self.delivery_process_no:
+            if hasattr(self.delivery_process_no, 'to_alipay_dict'):
+                params['delivery_process_no'] = self.delivery_process_no.to_alipay_dict()
+            else:
+                params['delivery_process_no'] = self.delivery_process_no
+        if self.delivery_process_supplier_id:
+            if hasattr(self.delivery_process_supplier_id, 'to_alipay_dict'):
+                params['delivery_process_supplier_id'] = self.delivery_process_supplier_id.to_alipay_dict()
+            else:
+                params['delivery_process_supplier_id'] = self.delivery_process_supplier_id
+        if self.delivery_process_supplier_name:
+            if hasattr(self.delivery_process_supplier_name, 'to_alipay_dict'):
+                params['delivery_process_supplier_name'] = self.delivery_process_supplier_name.to_alipay_dict()
+            else:
+                params['delivery_process_supplier_name'] = self.delivery_process_supplier_name
+        if self.delivery_supplier_full_name:
+            if hasattr(self.delivery_supplier_full_name, 'to_alipay_dict'):
+                params['delivery_supplier_full_name'] = self.delivery_supplier_full_name.to_alipay_dict()
+            else:
+                params['delivery_supplier_full_name'] = self.delivery_supplier_full_name
+        if self.delivery_supplier_id:
+            if hasattr(self.delivery_supplier_id, 'to_alipay_dict'):
+                params['delivery_supplier_id'] = self.delivery_supplier_id.to_alipay_dict()
+            else:
+                params['delivery_supplier_id'] = self.delivery_supplier_id
+        if self.delivery_supplier_name:
+            if hasattr(self.delivery_supplier_name, 'to_alipay_dict'):
+                params['delivery_supplier_name'] = self.delivery_supplier_name.to_alipay_dict()
+            else:
+                params['delivery_supplier_name'] = self.delivery_supplier_name
+        if self.ext_info:
+            if hasattr(self.ext_info, 'to_alipay_dict'):
+                params['ext_info'] = self.ext_info.to_alipay_dict()
+            else:
+                params['ext_info'] = self.ext_info
         if self.from_address:
             if hasattr(self.from_address, 'to_alipay_dict'):
                 params['from_address'] = self.from_address.to_alipay_dict()
@@ -287,6 +429,11 @@ class AssetDeliveryItem(object):
                 params['memo'] = self.memo.to_alipay_dict()
             else:
                 params['memo'] = self.memo
+        if self.operate_info:
+            if hasattr(self.operate_info, 'to_alipay_dict'):
+                params['operate_info'] = self.operate_info.to_alipay_dict()
+            else:
+                params['operate_info'] = self.operate_info
         if self.ou_code:
             if hasattr(self.ou_code, 'to_alipay_dict'):
                 params['ou_code'] = self.ou_code.to_alipay_dict()
@@ -356,10 +503,30 @@ class AssetDeliveryItem(object):
             o.assign_item_id = d['assign_item_id']
         if 'assign_out_order_id' in d:
             o.assign_out_order_id = d['assign_out_order_id']
+        if 'biz_line' in d:
+            o.biz_line = d['biz_line']
         if 'biz_tag' in d:
             o.biz_tag = d['biz_tag']
         if 'biz_type' in d:
             o.biz_type = d['biz_type']
+        if 'custom_clearance' in d:
+            o.custom_clearance = d['custom_clearance']
+        if 'delivery_assign_order_item_id' in d:
+            o.delivery_assign_order_item_id = d['delivery_assign_order_item_id']
+        if 'delivery_process_no' in d:
+            o.delivery_process_no = d['delivery_process_no']
+        if 'delivery_process_supplier_id' in d:
+            o.delivery_process_supplier_id = d['delivery_process_supplier_id']
+        if 'delivery_process_supplier_name' in d:
+            o.delivery_process_supplier_name = d['delivery_process_supplier_name']
+        if 'delivery_supplier_full_name' in d:
+            o.delivery_supplier_full_name = d['delivery_supplier_full_name']
+        if 'delivery_supplier_id' in d:
+            o.delivery_supplier_id = d['delivery_supplier_id']
+        if 'delivery_supplier_name' in d:
+            o.delivery_supplier_name = d['delivery_supplier_name']
+        if 'ext_info' in d:
+            o.ext_info = d['ext_info']
         if 'from_address' in d:
             o.from_address = d['from_address']
         if 'gmt_assign' in d:
@@ -372,6 +539,8 @@ class AssetDeliveryItem(object):
             o.logistics_info = d['logistics_info']
         if 'memo' in d:
             o.memo = d['memo']
+        if 'operate_info' in d:
+            o.operate_info = d['operate_info']
         if 'ou_code' in d:
             o.ou_code = d['ou_code']
         if 'ou_name' in d:
